Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1004)

Unified Diff: pkg/barback/lib/src/transformer/lazy_aggregate_transformer.dart

Issue 262173009: Add aggregate transformer types to barback. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 6 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/barback/lib/src/transformer/lazy_aggregate_transformer.dart
diff --git a/pkg/barback/lib/src/transformer/lazy_transformer.dart b/pkg/barback/lib/src/transformer/lazy_aggregate_transformer.dart
similarity index 59%
copy from pkg/barback/lib/src/transformer/lazy_transformer.dart
copy to pkg/barback/lib/src/transformer/lazy_aggregate_transformer.dart
index 657b65b70bfbe581c8edd22d203b47f6de92de68..891fc1ec29fbf361a7aff0f6b9dfb6247bfb3a3c 100644
--- a/pkg/barback/lib/src/transformer/lazy_transformer.dart
+++ b/pkg/barback/lib/src/transformer/lazy_aggregate_transformer.dart
@@ -2,15 +2,15 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
-library barback.transformer.lazy_transformer;
+library barback.transformer.lazy_aggregate_transformer;
-import 'declaring_transformer.dart';
+import 'declaring_aggregate_transformer.dart';
-/// An interface for [Transformer]s that indicates that the transformer's
-/// outputs shouldn't be generated until requested.
+/// An interface for [AggregateTransformer]s that indicates that the
+/// transformer's outputs shouldn't be generated until requested.
///
/// The [declareOutputs] method is used to figure out which assets should be
/// treated as "lazy." Lazy assets will only be forced to be generated if
/// they're requested by the user or if they're used by a non-declaring
/// transformer.
-abstract class LazyTransformer extends DeclaringTransformer {}
+abstract class LazyAggregateTransformer extends DeclaringAggregateTransformer {}
Bob Nystrom 2014/05/05 23:41:56 It seems like the Transformer class hierarchy is s
nweiz 2014/05/06 22:46:40 That doesn't sound like an important enough breaki

Powered by Google App Engine
This is Rietveld 408576698